@@ -38,7 +38,8 @@ sub create_file {
     	print FILE @_;
         return 1 if close FILE;
     }
-    $file =~ s/\s/\\s/g;
+    $file =~ s/\n/\\n/g;
+    $file =~ s/\s/\\ /g;
     diag "Can't create file \"$file\": $!\n";
     return;
 } 
